Changelog
---------

.. changelog::
    :changelog-url: https://wags-tails.readthedocs.io/en/stable/#changelog
    :github: https://github.com/genomicmedlab/wags-tails/releases/
    :pypi: https://pypi.org/project/wags-tails/
